@@ -17,12 +17,57 @@ class TovoBenasciutti(Narrowband):
     [3] Janko Slavič, Matjaž Mršnik, Martin Česnik, Jaka Javh, Miha Boltežar. 
         Vibration Fatigue by Spectral Methods, From Structural Dynamics to Fatigue Damage
         – Theory and Experiments, ISBN: 9780128221907, Elsevier, 1st September 2020
-        """
-    def __init__(self, spectral_data):
-        '''Get needed values from reference object.
+        
+    Example
+    -------
+    Import modules, define time- and frequency-domain data
 
-        :param spectral_data:  Instance of object SpectralData
-        '''     
+    >>> import FLife
+    >>> import pyExSi as es
+    >>> import numpy as np
+    >>> from matplotlib import pyplot as plt
+    >>> # time-domain data
+    >>> N = 2 ** 16  # number of data points of time signal
+    >>> fs = 2048  # sampling frequency [Hz]
+    >>> t = np.arange(0, N) / fs  # time vector
+    >>> # frequency-domain data
+    >>> M = N // 2 + 1  # number of data points of frequency vector
+    >>> freq = np.arange(0, M, 1) * fs / N  # frequency vector
+    >>> PSD_lower = es.get_psd(freq, 20, 60, variance = 5)  # lower mode of random process
+    >>> PSD_higher = es.get_psd(freq, 100, 120, variance = 2)  # higher mode of random process
+    >>> PSD = PSD_lower + PSD_higher # bimodal one-sided flat-shaped PSD
+
+    Get Gaussian stationary signal, instantiate SpectralData object and plot PSD
+
+    >>> rg = np.random.default_rng(123) # random generator seed
+    >>> x = es.random_gaussian(N, PSD, fs, rg) # Gaussian stationary signal
+    >>> sd = FLife.SpectralData(input=x, dt=1/fs) # SpectralData instance
+    >>> plt.plot(sd.psd[:,0], sd.psd[:,1]) 
+    >>> plt.xlabel('Frequency [Hz]')
+    >>> plt.ylabel('PSD')
+
+    Define S-N curve parameters and get fatigue-life estimatate
+
+    >>> C = 1.8e+22  # S-N curve intercept [MPa**k]
+    >>> k = 7.3 # S-N curve inverse slope [/]
+    >>> tb = FLife.TovoBenasciutti(sd)
+    >>> print(f'Fatigue life, method 1: {tb.get_life(C,k, method="method 1"):.3e} s.')
+    >>> print(f'Fatigue life, method 2: {tb.get_life(C,k, method="method 2"):.3e} s.')
+
+    Define stress vector and depict stress peak PDF
+
+    >>> s = np.arange(0,np.max(x),.01) 
+    >>> plt.plot(s,tb.get_PDF(s, method='method 1'), lw=5, alpha=.5, label = 'method 1')
+    >>> plt.plot(s,tb.get_PDF(s, method='method 2'), '--', label = 'method 2')
+    >>> plt.xlabel('Stress [MPa]')
+    >>> plt.ylabel('PDF')
+    >>> plt.legend()
+    """
+    def __init__(self, spectral_data):
+        """Get needed values from reference object.
+
+        :param spectral_data:  Instance of class SpectralData
+        """     
         Narrowband.__init__(self, spectral_data)
 
     def _calculate_coefficient(self, method='method 2'):
@@ -50,10 +95,10 @@ class TovoBenasciutti(Narrowband):
         
         :return b: float
         """
-        al1 = self.spectral_data.al1
-        al2 = self.spectral_data.al2
+        alpha1 = self.spectral_data.alpha1
+        alpha2 = self.spectral_data.alpha2
 
-        b = min( (al1-al2) / (1.0 - al1), 1.0)
+        b = min( (alpha1-alpha2) / (1.0 - alpha1), 1.0)
         
         return b
 
@@ -63,32 +108,35 @@ class TovoBenasciutti(Narrowband):
         
         :return b: float
         """
-        al1 = self.spectral_data.al1
-        al2 = self.spectral_data.al2
+        alpha1 = self.spectral_data.alpha1
+        alpha2 = self.spectral_data.alpha2
 
-        b = (al1-al2) * (  1.112 * ( 1+ al1*al2 - (al1+al2)  ) * np.exp(2.11*al2) +(al1-al2) ) / ((al2-1)**2)
+        b = (alpha1-alpha2) * (  1.112 * ( 1+ alpha1*alpha2 - (alpha1+alpha2)  ) * np.exp(2.11*alpha2) +(alpha1-alpha2) ) / ((alpha2-1)**2)
 
         return b
         
     def get_PDF(self, s, method='method 2'):
-        '''Returns cycle PDF(Probability Density Function) as a function of stress s.
+        """Returns cycle PDF(Probability Density Function) as a function of stress s.
 
         :param s:  numpy.ndarray
             Stress vector.
         :param method:  string
-            - 'method 1': `b` weighting parameter `b` is defined by Tovo[1].
-            - 'method 2': `b` weighting parameter `b` is defined by Tovo and Benasciutti [2].
-                          (This is the improved method)
-        :return pdf: function pdf(s)
-        '''
-        al2 = self.spectral_data.al2
+
+            - 'method 1': weighting parameter `b` is defined by Tovo[1].
+              
+            - 'method 2': weighting parameter `b` is defined by Tovo and Benasciutti [2].
+              (This is the improved method)
+
+        :return: function pdf(s)
+        """
+        alpha2 = self.spectral_data.alpha2
         m0 = self.spectral_data.moments[0]
 
         b = self._calculate_coefficient(method=method)
 
         def pdf(s):
             px = b * ((s / m0) * np.exp( - s**2 / (2 * m0))) + \
-                (1 - b) * ((s / (m0 * al2**2)) * np.exp( - s**2 / (2 * al2**2 * m0))) 
+                (1 - b) * ((s / (m0 * alpha2**2)) * np.exp( - s**2 / (2 * alpha2**2 * m0))) 
             return px
         return pdf(s)
 
@@ -97,17 +145,20 @@ class TovoBenasciutti(Narrowband):
 
         :param C: [int,float]
             S-N curve intercept [MPa**k].
-        :param k : [int,float]
+        :param k: [int,float]
             S-N curve inverse slope [/].
         :param method:  string
-            - 'method 1': `b` weighting parameter `b` is defined by Tovo[1].
-            - 'method 2': `b` weighting parameter `b` is defined by Tovo and Benasciutti [2].
-                          (This is the improved method)
+        
+            - 'method 1': weighting parameter `b` is defined by Tovo[1].
+            - 'method 2': weighting parameter `b` is defined by Tovo and Benasciutti [2].
+              (This is the improved method)
+
         :param integrate_pdf:  boolean
             If true the the fatigue life is estimated by integrating the PDF, 
             Default is false which means that the theoretical equation is used
-        :return T: float
+        :return:
             Estimated fatigue life in seconds.
+        :rtype: float
         """ 
         if integrate_pdf:
             d = self.spectral_data.nu / C * \
@@ -116,12 +167,12 @@ class TovoBenasciutti(Narrowband):
         else:
             m0 = self.spectral_data.moments[0]
             nu = self.spectral_data.nu
-            al2 = self.spectral_data.al2
+            alpha2 = self.spectral_data.alpha2
             
             b = self._calculate_coefficient(method=method)
 
             dNB = self.damage_intesity_NB(m0=m0, nu=nu, C=C, k=k) 
-            l = b + ( 1.0 - b ) * al2**(k-1.0)
+            l = b + ( 1.0 - b ) * alpha2**(k-1.0)
             d = dNB * l
         
         T = 1.0/d
